@@ -1,11 +1,17 @@
 from __future__ import annotations
 
-__all__ = ['QueueCommands', 'QueueRegistry', 'RunArg', 'set_queues', 'main']
+__all__ = [
+    'QueueCommands',
+    'QueueRegistry',
+    'RunArg',
+    'RunResult',
+    'set_queues',
+    'main',
+]
 
-from typing import Any, Tuple
 
 from .run import run_
-from .types import QueueCommands, QueueRegistry, RunArg
+from .types import QueueCommands, QueueRegistry, RunArg, RunResult
 
 _q_commands: QueueCommands | None = None
 _q_registry: QueueRegistry | None = None
@@ -18,7 +24,7 @@ def set_queues(q_commands: QueueCommands, q_registry: QueueRegistry) -> None:
     _q_registry = q_registry
 
 
-def main(run_arg: RunArg) -> Tuple[Any, BaseException | None]:
+def main(run_arg: RunArg) -> RunResult:
     '''The function to be submitted to ProcessPoolExecutor.'''
     assert _q_registry
     assert _q_commands
