@@ -5,8 +5,6 @@ import threading
 from contextlib import contextmanager
 from typing import TYPE_CHECKING, Optional
 
-from nextline.process.trace.wrap import FilterByModuleName
-
 if TYPE_CHECKING:
     from sys import TraceFunction as TraceFunc  # type: ignore  # noqa: F401
 
@@ -23,15 +21,38 @@ def sys_trace(trace_func: TraceFunc, thread: Optional[bool] = True):
 
     Example:
 
+    Define a trace function.
     >>> def trace_func(frame, event, arg):
-    ...     # will be skipped in the doctest because of TraceSkipModule
-    ...     return trace_func
+    ...     # Print the module name, function name, and event.
+    ...     module_name = frame.f_globals.get('__name__')
+    ...     func_name = frame.f_code.co_name
+    ...     print(f'trace_func(): {module_name}.{func_name}() # {event}')
+    ...
+    ...     # Return the trace function only if the function name is 'callable'.
+    ...     if func_name == 'callable':
+    ...         return trace_func
+    ...     return None
 
+    Define a callable to trace.
     >>> def callable():
-    ...     pass
+    ...     print('callable()')
 
+    Trace the callable.
     >>> with sys_trace(trace_func):
     ...     callable()
+    trace_func(): nextline.process.call.callable() # call
+    trace_func(): nextline.process.call.callable() # line
+    callable()
+    trace_func(): nextline.process.call.callable() # return
+    trace_func(): contextlib.__exit__() # call
+    trace_func(): nextline.process.call.sys_trace() # call
+
+
+    The callable is traced.
+
+    However, as can be seen in the output, after the callable returns, the
+    trace function continues to be called until sys.settrace(None) is called in
+    the finally clause.
 
     '''
     trace_func_org = sys.gettrace()
@@ -39,9 +60,6 @@ def sys_trace(trace_func: TraceFunc, thread: Optional[bool] = True):
     if thread:
         threading.settrace(trace_func)
 
-    # Skip the context manager and this module otherwise they will be traced after
-    # the yield is returned.
-    trace_func = FilterByModuleName(trace_func, {contextmanager.__module__, __name__})
     sys.settrace(trace_func)
 
     try:
